@@ -9,7 +9,7 @@
 use strict; use warnings;
 package POE::Component::SSLify;
 BEGIN {
-  $POE::Component::SSLify::VERSION = '1.000';
+  $POE::Component::SSLify::VERSION = '1.001';
 }
 BEGIN {
   $POE::Component::SSLify::AUTHORITY = 'cpan:APOCAL';
@@ -19,10 +19,8 @@ BEGIN {
 
 # We need Net::SSLeay or all's a failure!
 BEGIN {
-	eval {
-		# We need >= 1.36 because it contains a lot of important fixes
-		use Net::SSLeay 1.36 qw( die_now die_if_ssl_error );
-	};
+	# We need >= 1.36 because it contains a lot of important fixes
+	eval "use Net::SSLeay 1.36 qw( die_now die_if_ssl_error )";
 
 	# Check for errors...
 	if ( $@ ) {
@@ -223,7 +221,7 @@ POE::Component::SSLify - Makes using SSL in the world of POE easy!
 
 =head1 VERSION
 
-  This document describes v1.000 of POE::Component::SSLify - released February 12, 2011 as part of POE-Component-SSLify.
+  This document describes v1.001 of POE::Component::SSLify - released February 13, 2011 as part of POE-Component-SSLify.
 
 =head1 SYNOPSIS
 
